llm.sdk.cache.request

Request cache option readers.

Request cache option readers.
raw docstring

breakpointsclj

(breakpoints request)

Read and validate the cache breakpoint count from a request, defaulting to 4.

Read and validate the cache breakpoint count from a request, defaulting to 4.
sourceraw docstring

cache-enabled?clj

(cache-enabled? request)

Return true when the request opted in to caching.

Return true when the request opted in to caching.
sourceraw docstring

cached-content-idclj

(cached-content-id request)

Read the caller-supplied explicit cached content id.

Read the caller-supplied explicit cached content id.
sourceraw docstring

scope-idclj

(scope-id request)

Read the caller-supplied scope id.

Read the caller-supplied scope id.
sourceraw docstring

tools-cache?clj

(tools-cache? request)

Should tools[] schema be cached in addition to messages?

Should tools[] schema be cached in addition to messages?
sourceraw docstring

ttlclj

(ttl request)

Read and validate the cache TTL from a request, defaulting to '5m'.

Read and validate the cache TTL from a request, defaulting to '5m'.
sourceraw docstring

validate-breakpoints!clj

(validate-breakpoints! breakpoints)

Return count when it is a non-negative integer, otherwise throw.

Return count when it is a non-negative integer, otherwise throw.
sourceraw docstring

validate-ttl!clj

(validate-ttl! ttl)

Return ttl when supported, otherwise throw a request validation error.

Return ttl when supported, otherwise throw a request validation error.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries