llm.sdk.providers.bedrock.image

Bedrock Runtime image-generation adapter.

Amazon Titan Image Generator and Nova Canvas use the taskType / imageGenerationConfig request family. Stability SDXL uses the legacy text_prompts/artifacts contract, while Stable Image Core, Ultra, and SD3.5 use the prompt/images contract. All models are invoked through /model/{modelId}/invoke with SigV4.

Bedrock Runtime image-generation adapter.

Amazon Titan Image Generator and Nova Canvas use the taskType /
imageGenerationConfig request family. Stability SDXL uses the legacy
text_prompts/artifacts contract, while Stable Image Core, Ultra, and
SD3.5 use the prompt/images contract. All models are invoked through
/model/{modelId}/invoke with SigV4.
raw docstring

build-image-request-bedrockclj

(build-image-request-bedrock _profile request)
source

make-transportclj

(make-transport)
source

parse-image-error-bedrockclj

(parse-image-error-bedrock _profile status body)
source

parse-image-response-bedrockclj

(parse-image-response-bedrock _profile raw)
source

cljdoc builds & hosts documentation for Clojure/Script libraries