llm.sdk.providers.codex.auth

Managed ChatGPT OAuth credentials for the Codex backend.

Managed ChatGPT OAuth credentials for the Codex backend.
raw docstring

llm.sdk.providers.codex.responses

OpenAI Responses API (Codex) transport adapter. Covers both the standard OpenAI Responses API (api.openai.com) and the Codex backend (chatgpt.com/backend-api/codex).

For the Codex backend, auth is read from ~/.codex/auth.json (shared with the official OpenAI Codex CLI).

OpenAI Responses API (Codex) transport adapter.
Covers both the standard OpenAI Responses API (api.openai.com)
and the Codex backend (chatgpt.com/backend-api/codex).

For the Codex backend, auth is read from ~/.codex/auth.json
(shared with the official OpenAI Codex CLI).
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries