llm.sdk.providers.codex.responses

OpenAI Responses API (Codex) transport adapter. Covers both the standard OpenAI Responses API (api.openai.com) and the Codex backend (chatgpt.com/backend-api/codex).

For the Codex backend, auth is read from ~/.codex/auth.json (shared with the official OpenAI Codex CLI).

OpenAI Responses API (Codex) transport adapter.
Covers both the standard OpenAI Responses API (api.openai.com)
and the Codex backend (chatgpt.com/backend-api/codex).

For the Codex backend, auth is read from ~/.codex/auth.json
(shared with the official OpenAI Codex CLI).
raw docstring

build-request-codexclj

(build-request-codex profile request)
source

make-transportclj

(make-transport)
source

parse-error-codexclj

(parse-error-codex profile status body)
source

parse-response-codexclj

(parse-response-codex profile raw)
source

parse-stream-event-codexclj

(parse-stream-event-codex profile line)
source

cljdoc builds & hosts documentation for Clojure/Script libraries