llm.sdk.providers.cohere.rerank

Cohere /rerank transport. Jina uses the same core wire shape while also supporting structured returned documents and optional returned embeddings.

Cohere additionally returns :meta.billed_units.search_units for usage; Jina returns :usage {total_tokens}. Both are surfaced through the canonical :response/usage where possible.

Cohere /rerank transport. Jina uses the same core wire shape while also
supporting structured returned documents and optional returned embeddings.

Cohere additionally returns :meta.billed_units.search_units for
usage; Jina returns :usage {total_tokens}. Both are surfaced
through the canonical :response/usage where possible.
raw docstring

build-rerank-request-cohere-shapeclj

(build-rerank-request-cohere-shape profile request)
source

make-transportclj

(make-transport)
source

parse-rerank-error-cohere-shapeclj

(parse-rerank-error-cohere-shape profile status body)
source

parse-rerank-response-cohere-shapeclj

(parse-rerank-response-cohere-shape profile raw)
source

cljdoc builds & hosts documentation for Clojure/Script libraries