Clojure only.

llm.sdk.providers.fake.chat

Fake/test provider that returns deterministic responses. Conforms to the Transport protocol.

Fake/test provider that returns deterministic responses.
Conforms to the Transport protocol.
raw docstring

make-fake-transportclj

(make-fake-transport & {:keys [response-fn]})

Create a fake transport. Optionally pass a response-fn that receives the raw response and returns a canonical Response map.

Create a fake transport. Optionally pass a response-fn that receives
the raw response and returns a canonical Response map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries