Vertex AI image-generation adapter.
Google discontinued the Imagen prediction endpoints on 2026-06-30. The :vertex-imagen SDK identity now targets the documented replacement, Gemini image generation over Vertex generateContent.
Vertex AI image-generation adapter. Google discontinued the Imagen prediction endpoints on 2026-06-30. The :vertex-imagen SDK identity now targets the documented replacement, Gemini image generation over Vertex generateContent.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |