OpenRouter chat-completions transport. OpenRouter extends the OpenAI wire shape with top-level provider routing, plugins, reasoning, session routing, and detailed usage.
OpenRouter chat-completions transport. OpenRouter extends the OpenAI wire shape with top-level provider routing, plugins, reasoning, session routing, and detailed usage.
OpenRouter embeddings transport over the OpenAI-compatible /embeddings API.
OpenRouter embeddings transport over the OpenAI-compatible /embeddings API.
OpenRouter image generation transport for the native POST /images API.
OpenRouter image generation transport for the native POST /images API.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |