Request cache option readers.
Request cache option readers.
(breakpoints request)Read and validate the cache breakpoint count from a request, defaulting to 4.
Read and validate the cache breakpoint count from a request, defaulting to 4.
(cache-enabled? request)Return true when the request opted in to caching.
Return true when the request opted in to caching.
(cached-content-id request)Read the caller-supplied explicit cached content id.
Read the caller-supplied explicit cached content id.
(scope-id request)Read the caller-supplied scope id.
Read the caller-supplied scope id.
(tools-cache? request)Should tools[] schema be cached in addition to messages?
Should tools[] schema be cached in addition to messages?
(ttl request)Read and validate the cache TTL from a request, defaulting to '5m'.
Read and validate the cache TTL from a request, defaulting to '5m'.
(validate-breakpoints! breakpoints)Return count when it is a non-negative integer, otherwise throw.
Return count when it is a non-negative integer, otherwise throw.
(validate-ttl! ttl)Return ttl when supported, otherwise throw a request validation error.
Return ttl when supported, otherwise throw a request validation error.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |