Request cache option readers.
Request cache option readers.
(breakpoints request)Read the cache breakpoint count from a request, defaulting to 4.
Read the cache breakpoint count from a request, defaulting to 4.
(cache-enabled? request)Return true when the request opted in to caching.
Return true when the request opted in to caching.
(cached-content-id request)Read the caller-supplied explicit cached content id.
Read the caller-supplied explicit cached content id.
(scope-id request)Read the caller-supplied scope id.
Read the caller-supplied scope id.
(tools-cache? request)Should tools[] schema be cached in addition to messages?
Should tools[] schema be cached in addition to messages?
(ttl request)Read the cache TTL from a request, defaulting to '5m'.
Read the cache TTL from a request, defaulting to '5m'.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |