Structured error classification. Ported from Hermes error_classifier.py with simplified pipeline.
Structured error classification. Ported from Hermes error_classifier.py with simplified pipeline.
(classify-api-error provider label status body)Classify a provider HTTP API error with a consistent exception label.
Classify a provider HTTP API error with a consistent exception label.
(classify-error e & {:keys [status body error-type]})Classify an exception or error response into a structured map. Options: :status HTTP status code (int or nil) :body Response body (map or string) :provider Provider keyword :model Model string :error-type Exception type name string
Classify an exception or error response into a structured map. Options: :status HTTP status code (int or nil) :body Response body (map or string) :provider Provider keyword :model Model string :error-type Exception type name string
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |