Bedrock Runtime image-generation adapter.
Amazon Titan Image Generator and Nova Canvas use the taskType / imageGenerationConfig request family. Stability SDXL uses the legacy text_prompts/artifacts contract, while Stable Image Core, Ultra, and SD3.5 use the prompt/images contract. All models are invoked through /model/{modelId}/invoke with SigV4.
Bedrock Runtime image-generation adapter.
Amazon Titan Image Generator and Nova Canvas use the taskType /
imageGenerationConfig request family. Stability SDXL uses the legacy
text_prompts/artifacts contract, while Stable Image Core, Ultra, and
SD3.5 use the prompt/images contract. All models are invoked through
/model/{modelId}/invoke with SigV4.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |