Managed ChatGPT OAuth credentials for the Codex backend.
Managed ChatGPT OAuth credentials for the Codex backend.
OpenAI Responses API (Codex) transport adapter. Covers both the standard OpenAI Responses API (api.openai.com) and the Codex backend (chatgpt.com/backend-api/codex).
For the Codex backend, auth is read from ~/.codex/auth.json (shared with the official OpenAI Codex CLI).
OpenAI Responses API (Codex) transport adapter. Covers both the standard OpenAI Responses API (api.openai.com) and the Codex backend (chatgpt.com/backend-api/codex). For the Codex backend, auth is read from ~/.codex/auth.json (shared with the official OpenAI Codex CLI).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |