Cohere /rerank transport. Jina uses the same core wire shape while also supporting structured returned documents and optional returned embeddings.
Cohere additionally returns :meta.billed_units.search_units for usage; Jina returns :usage {total_tokens}. Both are surfaced through the canonical :response/usage where possible.
Cohere /rerank transport. Jina uses the same core wire shape while also
supporting structured returned documents and optional returned embeddings.
Cohere additionally returns :meta.billed_units.search_units for
usage; Jina returns :usage {total_tokens}. Both are surfaced
through the canonical :response/usage where possible.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |