Fake/test provider that returns deterministic responses. Conforms to the Transport protocol.
Fake/test provider that returns deterministic responses. Conforms to the Transport protocol.
(make-fake-transport & {:keys [response-fn]})Create a fake transport. Optionally pass a response-fn that receives the raw response and returns a canonical Response map.
Create a fake transport. Optionally pass a response-fn that receives the raw response and returns a canonical Response map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |