OpenAI image generation adapter.
POST {base}/images/generations. A model is required because the former implicit DALL-E models were retired on 2026-05-12. Explicit caller-selected DALL-E 2/3 requests retain their documented wire contracts; GPT Image requests use the current GPT-specific contract.
OpenAI image generation adapter.
POST {base}/images/generations. A model is required because the former
implicit DALL-E models were retired on 2026-05-12. Explicit caller-selected
DALL-E 2/3 requests retain their documented wire contracts; GPT Image
requests use the current GPT-specific contract.(parse-image-stream-event-openai profile line)Normalize current image_generation.partial_image/completed SSE events.
ImageTransport is request/response-only, so this function is also exposed
directly for callers opting into :stream true via provider-options.
Normalize current image_generation.partial_image/completed SSE events. ImageTransport is request/response-only, so this function is also exposed directly for callers opting into `:stream true` via provider-options.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |