Perplexity Agent API transport. Builds /v1/agent requests and normalizes typed output and SSE events while retaining the provider's response, tool-call, search, lifecycle, and billing state.
Perplexity Agent API transport. Builds /v1/agent requests and normalizes typed output and SSE events while retaining the provider's response, tool-call, search, lifecycle, and billing state.
(extract-citation-parts raw)Return Agent API citations. Search-result output is authoritative and carries stable numeric IDs; URL annotations are used when no search-result output is present.
Return Agent API citations. Search-result output is authoritative and carries stable numeric IDs; URL annotations are used when no search-result output is present.
(perplexity-cost-calculator {:keys [_provider _model usage pricing]})Estimate from catalog pricing when an Agent response did not report its authoritative usage.cost. Search-query pricing is added when present.
Estimate from catalog pricing when an Agent response did not report its authoritative usage.cost. Search-query pricing is added when present.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |