Canonical request/response schemas for the LLM SDK. All provider adapters translate to/from these shapes.
Canonical request/response schemas for the LLM SDK. All provider adapters translate to/from these shapes.
A provider citation. URLs are optional because document and tool-output citations may identify only an opaque source or location.
A provider citation. URLs are optional because document and tool-output citations may identify only an opaque source or location.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |